# face-projection

Add a short description here!


## Note

> This is the main page of your project's [Sphinx] documentation. It is
> formatted in [Markdown]. Add additional pages by creating md-files in
> `docs` or rst-files (formated in [reStructuredText]) and adding links to
> them in the `Contents` section below.
>
> Please check [Sphinx], [recommonmark] and [autostructify] for more information
> about how to document your project and how to configure your preferences.


## Contents

* [Overview](readme)
* [License](license)
* [Authors](authors)
* [Changelog](changelog)
* [Module Reference](api/modules)


## Indices and tables

```eval_rst
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
```

[Sphinx]: http://www.sphinx-doc.org/
[Markdown]: https://daringfireball.net/projects/markdown/
[reStructuredText]: http://www.sphinx-doc.org/en/master/usage/restructuredtext/basics.html
[recommonmark]: https://recommonmark.readthedocs.io/en/latest
[autostructify]: https://recommonmark.readthedocs.io/en/latest/auto_structify.html
